/*
Listing of all the Z80 Mnemonics in op-code order. The following codes
are used to indicate data items:

  & - Byte constant.
  ? - Word constant.
  # - Absolute address (word, data).
  ~ - Absolute address (byte, data).
  ! - Absolute address (code).
  $ - Relative offset (short jump).
  : - RST Address.
  @ - Indexed address.
  % - Index register.
  ^ - I/O port.
  * - Invalid op-code.

*/

// First op-codes without prefix:

static const char *psMnem[256]   =  {
   "NOP","LD BC,?","LD (BC),A","INC BC",           // 00
   "INC B","DEC B","LD B,&","RLCA",                // 04
   "EX AF,AF'","ADD %,BC","LD A,(BC)","DEC BC",    // 08
   "INC C","DEC C","LD C,&","RRCA",                // 0C
   "DJNZ $","LD DE,?","LD (DE),A","INC DE",        // 10
   "INC D","DEC D","LD D,&","RLA",                 // 14
   "JR $","ADD %,DE","LD A,(DE)","DEC DE",         // 18
   "INC E","DEC E","LD E,&","RRA",                 // 1C
   "JR NZ,$","LD %,?","LD (#),%","INC %",          // 20
   "INC H","DEC H","LD H,&","DAA",                 // 24
   "JR Z,$","ADD %,%","LD %,(#)","DEC %",          // 28
   "INC L","DEC L","LD L,&","CPL",                 // 2C
   "JR NC,$","LD SP,?","LD (~),A","INC SP",        // 30
   "INC @","DEC @","LD @,&","SCF",                 // 34
   "JR C,$","ADD %,SP","LD A,(~)","DEC SP",        // 38
   "INC A","DEC A","LD A,&","CCF",                 // 3C
   "LD B,B","LD B,C","LD B,D","LD B,E",            // 40
   "LD B,H","LD B,L","LD B,@","LD B,A",            // 44
   "LD C,B","LD C,C","LD C,D","LD C,E",            // 48
   "LD C,H","LD C,L","LD C,@","LD C,A",            // 4C
   "LD D,B","LD D,C","LD D,D","LD D,E",            // 50
   "LD D,H","LD D,L","LD D,@","LD D,A",            // 54
   "LD E,B","LD E,C","LD E,D","LD E,E",            // 58
   "LD E,H","LD E,L","LD E,@","LD E,A",            // 5C
   "LD H,B","LD H,C","LD H,D","LD H,E",            // 60
   "LD H,H","LD H,L","LD H,@","LD H,A",            // 64
   "LD L,B","LD L,C","LD L,D","LD L,E",            // 68
   "LD L,H","LD L,L","LD L,@","LD L,A",            // 6C
   "LD @,B","LD @,C","LD @,D","LD @,E",            // 70
   "LD @,H","LD @,L","HALT","LD @,A",              // 74
   "LD A,B","LD A,C","LD A,D","LD A,E",            // 78
   "LD A,H","LD A,L","LD A,@","LD A,A",            // 7C
   "ADD A,B","ADD A,C","ADD A,D","ADD A,E",        // 80
   "ADD A,H","ADD A,L","ADD A,@","ADD A,A",        // 84
   "ADC A,B","ADC A,C","ADC A,D","ADC A,E",        // 88
   "ADC A,H","ADC A,L","ADC A,@","ADC A,A",        // 8C
   "SUB B","SUB C","SUB D","SUB E",                // 90
   "SUB H","SUB L","SUB @","SUB A",                // 94
   "SBC A,B","SBC A,C","SBC A,D","SBC A,E",        // 98
   "SBC A,H","SBC A,L","SBC A,@","SBC A,A",        // 9C
   "AND B","AND C","AND D","AND E",                // A0
   "AND H","AND L","AND @","AND A",                // A4
   "XOR B","XOR C","XOR D","XOR E",                // A8
   "XOR H","XOR L","XOR @","XOR A",                // AC
   "OR B","OR C","OR D","OR E",                    // B0
   "OR H","OR L","OR @","OR A",                    // B4
   "CP B","CP C","CP D","CP E",                    // B8
   "CP H","CP L","CP @","CP A",                    // BC
   "RET NZ","POP BC","JP NZ,!","JP !",             // C0
   "CALL NZ,!","PUSH BC","ADD A,&","RST :",        // C4
   "RET Z","RET","JP Z,!","*",                     // C8
   "CALL Z,!","CALL !","ADC A,&","RST :",          // CC
   "RET NC","POP DE","JP NC,!","OUT (^),A",        // D0
   "CALL NC,!","PUSH DE","SUB &","RST :",          // D4
   "RET C","EXX","JP C,!","IN A,(^)",              // D8
   "CALL C,!","*","SBC A,&","RST :",               // DC
   "RET PO","POP %","JP PO,!","EX (SP),HL",        // E0
   "CALL PO,!","PUSH %","AND &","RST :",           // E4   
   "RET PE","JP (HL)","JP PE,!","EX DE,HL",        // E8
   "CALL PE,!","*","XOR &","RST :",                // EC
   "RET P","POP AF","JP P,!","DI",                 // F0
   "CALL P,!","PUSH AF","OR &","RST :",            // F4
   "RET M","LD SP,HL","JP M,!","EI",               // F8
   "CALL M,!","*","CP &","RST :" };                // FC

// Next the op-codes with a CB prefix:

static const char *psMnemCB[256] =  {
   "RLC B","RLC C","RLC D","RLC E",                // 00
   "RLC H","RLC L","RLC @","RLC A",                // 04
   "RRC B","RRC C","RRC D","RRC E",                // 08
   "RRC H","RRC L","RRC @","RRC A",                // 0C
   "RL B","RL C","RL D","RL E",                    // 10
   "RL H","RL L","RL @","RL A",                    // 14
   "RR B","RR C","RR D","RR E",                    // 18
   "RR H","RR L","RR @","RR A",                    // 1C
   "SLA B","SLA C","SLA D","SLA E",                // 20
   "SLA H","SLA L","SLA @","SLA A",                // 24
   "SRA B","SRA C","SRA D","SRA E",                // 28
   "SRA H","SRA L","SRA @","SRA A",                // 2C
   "*","*","*","*",                                // 30
   "*","*","*","*",                                // 34
   "SRL B","SRL C","SRL D","SRL E",                // 38
   "SRL H","SRL L","SRL @","SRL A",                // 3C
   "BIT 0,B","BIT 0,C","BIT 0,D","BIT 0,E",        // 40
   "BIT 0,H","BIT 0,L","BIT 0,@","BIT 0,A",        // 44
   "BIT 1,B","BIT 1,C","BIT 1,D","BIT 1,E",        // 48
   "BIT 1,H","BIT 1,L","BIT 1,@","BIT 1,A",        // 4C
   "BIT 2,B","BIT 2,C","BIT 2,D","BIT 2,E",        // 50
   "BIT 2,H","BIT 2,L","BIT 2,@","BIT 2,A",        // 54
   "BIT 3,B","BIT 3,C","BIT 3,D","BIT 3,E",        // 58
   "BIT 3,H","BIT 3,L","BIT 3,@","BIT 3,A",        // 5C
   "BIT 4,B","BIT 4,C","BIT 4,D","BIT 4,E",        // 60
   "BIT 4,H","BIT 4,L","BIT 4,@","BIT 4,A",        // 64
   "BIT 5,B","BIT 5,C","BIT 5,D","BIT 5,E",        // 68
   "BIT 5,H","BIT 5,L","BIT 5,@","BIT 5,A",        // 6C
   "BIT 6,B","BIT 6,C","BIT 6,D","BIT 6,E",        // 70
   "BIT 6,H","BIT 6,L","BIT 6,@","BIT 6,A",        // 74
   "BIT 7,B","BIT 7,C","BIT 7,D","BIT 7,E",        // 78
   "BIT 7,H","BIT 7,L","BIT 7,@","BIT 7,A",        // 7C
   "RES 0,B","RES 0,C","RES 0,D","RES 0,E",        // 80
   "RES 0,H","RES 0,L","RES 0,@","RES 0,A",        // 84
   "RES 1,B","RES 1,C","RES 1,D","RES 1,E",        // 88
   "RES 1,H","RES 1,L","RES 1,@","RES 1,A",        // 8C
   "RES 2,B","RES 2,C","RES 2,D","RES 2,E",        // 90
   "RES 2,H","RES 2,L","RES 2,@","RES 2,A",        // 94
   "RES 3,B","RES 3,C","RES 3,D","RES 3,E",        // 98
   "RES 3,H","RES 3,L","RES 3,@","RES 3,A",        // 9C
   "RES 4,B","RES 4,C","RES 4,D","RES 4,E",        // A0
   "RES 4,H","RES 4,L","RES 4,@","RES 4,A",        // A4
   "RES 5,B","RES 5,C","RES 5,D","RES 5,E",        // A8
   "RES 5,H","RES 5,L","RES 5,@","RES 5,A",        // AC
   "RES 6,B","RES 6,C","RES 6,D","RES 6,E",        // B0
   "RES 6,H","RES 6,L","RES 6,@","RES 6,A",        // B4
   "RES 7,B","RES 7,C","RES 7,D","RES 7,E",        // B8
   "RES 7,H","RES 7,L","RES 7,@","RES 7,A",        // BC
   "SET 0,B","SET 0,C","SET 0,D","SET 0,E",        // C0
   "SET 0,H","SET 0,L","SET 0,@","SET 0,A",        // C4
   "SET 1,B","SET 1,C","SET 1,D","SET 1,E",        // C8
   "SET 1,H","SET 1,L","SET 1,@","SET 1,A",        // CC
   "SET 2,B","SET 2,C","SET 2,D","SET 2,E",        // D0
   "SET 2,H","SET 2,L","SET 2,@","SET 2,A",        // D4
   "SET 3,B","SET 3,C","SET 3,D","SET 3,E",        // D8
   "SET 3,H","SET 3,L","SET 3,@","SET 3,A",        // DC
   "SET 4,B","SET 4,C","SET 4,D","SET 4,E",        // E0
   "SET 4,H","SET 4,L","SET 4,@","SET 4,A",        // E4
   "SET 5,B","SET 5,C","SET 5,D","SET 5,E",        // E8
   "SET 5,H","SET 5,L","SET 5,@","SET 5,A",        // EC
   "SET 6,B","SET 6,C","SET 6,D","SET 6,E",        // F0
   "SET 6,H","SET 6,L","SET 6,@","SET 6,A",        // F4
   "SET 7,B","SET 7,C","SET 7,D","SET 7,E",        // F8
   "SET 7,H","SET 7,L","SET 7,@","SET 7,A" };      // FC

// Finally op-codes with ED prefix:

static const char *psMnemED[88] =  {
   "IN B,(C)","OUT (C),B","SBC HL,BC","LD (#),BC", // 40
   "NEG","RETN","IM 0","LD I,A",                   // 44
   "IN C,(C)","OUT (C),C","ADC HL,BC","LD BC,(#)", // 48
   "*","RETI","*","LD R,A",                        // 4C
   "IN D,(C)","OUT (C),D","SBC HL,DE","LD (#),DE", // 50
   "*","*","IM 1","LD A,I",                        // 54
   "IN E,(C)","OUT (C),E","ADC HL,DE","LD DE,(#)", // 58
   "*","*","*","LD A,R",                           // 5C
   "IN H,(C)","OUT (C),H","SBC HL,HL","LD (#),HL", // 60
   "*","*","IM 2","RRD",                           // 64
   "IN L,(C)","OUT (C),L","ADC HL,HL","LD HL,(#)", // 68
   "*","*","*","RLD",                              // 6C
   "*","*","SBC HL,SP","LD (#),SP",                // 70
   "*","*","*","*",                                // 74
   "IN A,(C)","OUT (C),A","ADC HL,SP","LD SP,(#)", // 78
   "LDI","CPI","INI","OUTI",                       // A0
   "*","*","*","*",                                // A4
   "LDD","CPD","IND","OUTD",                       // A8
   "*","*","*","*",                                // AC
   "LDIR","CPIR","INIR","OTIR",                    // B0
   "*","*","*","*",                                // B4
   "LDDR","CPDR","INDR","OTDR" };                  // B8
